"use client";
import { formatNumberWithCommas } from "@/utils/formatPrice";
import { LoadingButton } from "@mui/lab";
import { Clock, People } from "iconsax-react";
import DiscountPriceCounter from "../common/counter/DiscountPriceCounter";
import InsideProductDisountRenderer from "../common/cards/components/InsideProductDisountRenderer";
import InsideProductPriceRenderer from "../common/cards/components/InsideProductPriceRenderer";

const ProductSideBarSection = ({ product }) => {
  const {
    name,
    // score,
    desc,
    image,
    price,
    finalPrice,
    discountedPrice,
    discountPercent,
    discountEndTime,
    hasDiscount,
    url,
  } = product;
  return (
    <>
      <div className="w-[390px] min-w-[390px] h-fit sticky top-[70px] hidden lg:flex flex-col gap-6 p-4 rounded-2xl shadow-base bg-background-main">
        <InsideProductDisountRenderer
          hasDiscount={hasDiscount}
          discountEndTime={discountEndTime}
        />
        <h2 className="font-bold text-base leading-9">{name}</h2>
        <InsideProductPriceRenderer
          hasDiscound={hasDiscount}
          price={price}
          discountedPrice={discountedPrice}
          discountPercent={discountPercent}
          finalPrice={finalPrice}
        />
      
        <LoadingButton variant="contained" className="font-bold">
          افزودن به سبد خرید
        </LoadingButton>
        <div className="w-full flex items-center gap-2 text-sm text-text-third">
          <People size={24} color="#516163" />
          <p>1036 نفر دیگر این محصول را خریده اند .</p>
        </div>
      </div>

      {/* mobile section */}
      <div className="w-full fixed bottom-0 left-0 right-0 lg:hidden h-fit max-h-[108px] md:h-[74px] bg-background-main border border-border-main flex items-center justify-center z-50">
        <div className="w-full h-full px-4 py-3 flex justify-between">
          <div className="flex max-w-fit flex-col flex-1 h-full md:flex-row items-center  gap-1  md:gap-3 ">
            <span className="text-text-second text-xs">
              <strong className="text-text-main text-sm">
                {formatNumberWithCommas(89000)}
              </strong>{" "}
              تومان{" "}
            </span>
            <div className="flex items-center gap-2">
              <div className="p-1 flex items-center justify-center rounded-lg bg-secondary-main">
                <strong className="text-white text-xs">%10</strong>
              </div>
              <p className="line-through text-text-second text-xs">
                {formatNumberWithCommas(135000)}
              </p>
            </div>
            <div className="flex items-center gap-3 text-white bg-secondary-300 rounded-lg px-2 py-1 w-[75px] ">
              <DiscountPriceCounter endTime={Date.now() + 140000} />
              <Clock color="white" size={14} />
            </div>
          </div>

          <div className="min-h-full flex items-center justify-center ">
            <LoadingButton variant="contained">
              افزودن به سبد خرید
            </LoadingButton>
          </div>
        </div>
      </div>
    </>
  );
};

export default ProductSideBarSection;
